@@ -1,5 +1,5 @@
 rysgran.plot <-
-function (x=NULL , y=NULL , data=NULL , lang="en-US",method="folk",
+function (x=NULL , y=NULL , data=NULL, output = "phi", lang="en-US", method="folk",
 main = NULL, xlab = NULL, ylab = NULL, show.labels = FALSE, 
 label.points = FALSE, pch = 1, col.labels = "black",
 labels = NULL, col = "black", cex.labels = 1, cex.points = 1,
@@ -10,19 +10,19 @@ pos=1, z.cex.range=NULL, z=NULL,...)
  a<-0
  b<-0
 
-tab<-gran.stats(tab=tab1, method=method, verbal=FALSE, lang="en-US")
+tab<-gran.stats(data=tab1, output=output, method=method, verbal=FALSE, lang="en-US")
 
 
 
  if (lang=="en-US" | lang=="en-GR"| lang=="eng"| lang=="e")
  {
   title<-as.character(c("Bivariated Plot"))
-  if (x=="mean" | x=="Mean" | x=="Mdia" | x=="Media" | x=="mdia" | x=="media")
+  if (x=="mean" | x=="Mean" | x=="M\u00E9dia" | x=="Media" | x=="m\u00E9dia" | x=="media")
   {
    a<-as.matrix(tab$Mean);colnames(a)<-c("Mean")
   }
 
-  if (x=="Sorting" | x=="sorting" | x=="sort" | x=="Sort" | x=="Seleo" | x=="Seleao" | x=="Selecao" | x=="seleo" | x=="seleao" | x=="selecao" | x=="Sele" | x=="sele")
+  if (x=="Sorting" | x=="sorting" | x=="sort" | x=="Sort" | x=="Sele\u00E7\u00E3o" | x=="Sele\u00E7ao" | x=="Selecao" | x=="sele\u00E7\u00E3o" | x=="sele\u00E7ao" | x=="selecao" | x=="Sele" | x=="sele")
   {
    a<-as.matrix(tab$Sorting);colnames(a)<-c("Sorting")
   }
@@ -37,12 +37,12 @@ tab<-gran.stats(tab=tab1, method=method, verbal=FALSE, lang="en-US")
    a<-as.matrix(tab$Kurtosis);colnames(a)<-c("Kurtosis")
   }
 
-  if (y=="Mean" | y=="mean" | y=="Mdia" | y=="Media" | y=="mdia" | y=="media")
+  if (y=="Mean" | y=="mean" | y=="M\u00E9dia" | y=="Media" | y=="m\u00E9dia" | y=="media")
   {
    b<-as.matrix(tab$Mean);colnames(b)<-c("Mean")
   }
 
-  if (y=="Sorting" | y=="sorting" | y=="Sort" | y=="sort" | y=="Seleo" | y=="Seleao" | y=="Selecao" | y=="seleo" | y=="seleao" | y=="selecao" | y=="Sele" | y=="sele")
+  if (y=="Sorting" | y=="sorting" | y=="Sort" | y=="sort" | y=="Sele\u00E7\u00E3o" | y=="Sele\u00E7ao" | y=="Selecao" | y=="sele\u00E7\u00E3o" | y=="sele\u00E7ao" | y=="selecao" | y=="Sele" | y=="sele")
   {
    b<-as.matrix(tab$Sorting);colnames(b)<-c("Sorting")
   }
@@ -60,15 +60,15 @@ tab<-gran.stats(tab=tab1, method=method, verbal=FALSE, lang="en-US")
 
  if (lang=="pt-BR" | lang=="pt-PT"| lang=="port"| lang=="p")
  {
-  title<-as.character(c("Grfico Bivariado"))
-  if (x=="mean" | x=="Mean" | x=="Mdia" | x=="Media" | x=="mdia" | x=="media")
+  title<-as.character(c("Gr\u00E1fico Bivariado"))
+  if (x=="mean" | x=="Mean" | x=="M\u00E9dia" | x=="Media" | x=="m\u00E9dia" | x=="media")
   {
-   a<-as.matrix(tab$Mean);colnames(a)<-c("Mdia") 
+   a<-as.matrix(tab$Mean);colnames(a)<-c("M\u00E9dia") 
   }
 
-  if (x=="Sorting" | x=="sorting" | x=="sort" | x=="Sort" | x=="Seleo" | x=="Seleao" | x=="Selecao" | x=="seleo" | x=="seleao" | x=="selecao" | x=="Sele" | x=="sele")
+  if (x=="Sorting" | x=="sorting" | x=="sort" | x=="Sort" | x=="Sele\u00E7\u00E3o" | x=="Sele\u00E7ao" | x=="Selecao" | x=="sele\u00E7\u00E3o" | x=="sele\u00E7ao" | x=="selecao" | x=="Sele" | x=="sele")
   {
-   a<-as.matrix(tab$Sorting);colnames(a)<-c("Seleo")
+   a<-as.matrix(tab$Sorting);colnames(a)<-c("Sele\u00E7\u00E3o")
   }
 
   if (x=="Skewness" | x=="skewness" | x=="Skew" | x=="skew" | x=="Assimetria" | x=="assimetria" | x=="Ass" | x=="ass")
@@ -81,14 +81,14 @@ tab<-gran.stats(tab=tab1, method=method, verbal=FALSE, lang="en-US")
    a<-as.matrix(tab$Kurtosis);colnames(a)<-c("Curtose")
   }
 
-  if (y=="Mean" | y=="mean" | y=="Mdia" | y=="Media" | y=="mdia" | y=="media")
+  if (y=="Mean" | y=="mean" | y=="M\u00E9dia" | y=="Media" | y=="m\u00E9dia" | y=="media")
   {
-   b<-as.matrix(tab$Mean);colnames(b)<-c("Mdia")
+   b<-as.matrix(tab$Mean);colnames(b)<-c("M\u00E9dia")
   }
 
-  if (y=="Sorting" | y=="sorting" | y=="Sort" | y=="sort" | y=="Seleo" | y=="Seleao" | y=="Selecao" | y=="seleo" | y=="seleao" | y=="selecao" | y=="Sele" | y=="sele")
+  if (y=="Sorting" | y=="sorting" | y=="Sort" | y=="sort" | y=="Sele\u00E7\u00E3o" | y=="Sele\u00E7ao" | y=="Selecao" | y=="sele\u00E7\u00E3o" | y=="sele\u00E7ao" | y=="selecao" | y=="Sele" | y=="sele")
   {
-   b<-as.matrix(tab$Sorting);colnames(b)<-c("Seleo")  
+   b<-as.matrix(tab$Sorting);colnames(b)<-c("Sele\u00E7\u00E3o")  
   }
 
   if (y=="Skewness" | y=="skewness" | y=="Skew" | y=="skew" | y=="Assimetria" | y=="assimetria" | y=="Ass" | y=="ass")
